==> epathmap-1.4.3-sources.jar: com/shitu/epathmap/model/bean/CarCheckData.java <==
package com.shitu.epathmap.model.bean;

import java.util.Date;

/**
 * author:lfei
 */

public class CarCheckData {


    private String floor = null;
    private String objectId = null;
    private Boolean isFinish = false;
    private String regionName = null;
    private String project = null;
    private Date createAt = null;
    private Date updatedAt = null;
    private boolean hasStop = false;

    private double latitude = 0.0;
    private double longitude = 0.0;

    public double getLatitude() {
        return latitude;
    }

    public void setLatitude(double latitude) {
        this.latitude = latitude;
    }

    public double getLongitude() {
        return longitude;
    }

    public void setLongitude(double longitude) {
        this.longitude = longitude;
    }

    public void  clear(){

        floor = null;
       latitude = 0.0;
       longitude = 0.0;
        objectId = null;
        isFinish = false;
        regionName = null;
        project = null;
        createAt = null;
        updatedAt = null;
        hasStop = false;
    }

    public boolean isHasStop() {
        return hasStop;
    }

    public void setHasStop(boolean hasStop) {
        this.hasStop = hasStop;
    }

    public String getObjectId() {
        return objectId;
    }

    public void setObjectId(String objectId) {
        this.objectId = objectId;
    }

    public Date getCreateAt() {
        return createAt;
    }

    public void setCreateAt(Date createAt) {
        this.createAt = createAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public String getProject() {
        return project;
    }

    public void setProject(String project) {
        this.project = project;
    }


    public String getFloor() {
        return floor;
    }

    public void setFloor(String floor) {
        this.floor = floor;
    }

    public Boolean getFinish() {
        return isFinish;
    }

    public void setFinish(Boolean finish) {
        isFinish = finish;
    }

    public String getRegionName() {
        return regionName;
    }

    public void setRegionName(String regionName) {
        this.regionName = regionName;
    }

    @Override
    public String toString() {
        return "CarCheckData{" +
                "floor='" + floor + '\'' +
                ", objectId='" + objectId + '\'' +
                ", isFinish=" + isFinish +
                ", regionName='" + regionName + '\'' +
                ", project='" + project + '\'' +
                ", createAt=" + createAt +
                ", updatedAt=" + updatedAt +
                ", hasStop=" + hasStop +
                ", latitude=" + latitude +
                ", longitude=" + longitude +
                '}';
    }
}

==> epathmap-1.9.1-sources.jar: com/shitu/epathmap/model/bean/CarCheckData.java <==
package com.shitu.epathmap.model.bean;

import com.google.gson.annotations.SerializedName;

import java.util.Date;

/**
 * author:lfei
 */

public class CarCheckData {


    @SerializedName(value = "body", alternate = {"apple","orange","banana","potato"})
    private String floor = null;
    private String objectId = null;
    private Boolean isFinish = false;
    private String regionName = null;
    private String project = null;
    private Date createAt = null;
    private Date updatedAt = null;
    private boolean hasStop = false;

    private double latitude = 0.0;
    private double longitude = 0.0;

    public double getLatitude() {
        return latitude;
    }

    public void setLatitude(double latitude) {
        this.latitude = latitude;
    }

    public double getLongitude() {
        return longitude;
    }

    public void setLongitude(double longitude) {
        this.longitude = longitude;
    }

    public void  clear(){

        floor = null;
       latitude = 0.0;
       longitude = 0.0;
        objectId = null;
        isFinish = false;
        regionName = null;
        project = null;
        createAt = null;
        updatedAt = null;
        hasStop = false;
    }

    public boolean isHasStop() {
        return hasStop;
    }

    public void setHasStop(boolean hasStop) {
        this.hasStop = hasStop;
    }

    public String getObjectId() {
        return objectId;
    }

    public void setObjectId(String objectId) {
        this.objectId = objectId;
    }

    public Date getCreateAt() {
        return createAt;
    }

    public void setCreateAt(Date createAt) {
        this.createAt = createAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public String getProject() {
        return project;
    }

    public void setProject(String project) {
        this.project = project;
    }


    public String getFloor() {
        return floor;
    }

    public void setFloor(String floor) {
        this.floor = floor;
    }

    public Boolean getFinish() {
        return isFinish;
    }

    public void setFinish(Boolean finish) {
        isFinish = finish;
    }

    public String getRegionName() {
        return regionName;
    }

    public void setRegionName(String regionName) {
        this.regionName = regionName;
    }

    @Override
    public String toString() {
        return "CarCheckData{" +
                "floor='" + floor + '\'' +
                ", objectId='" + objectId + '\'' +
                ", isFinish=" + isFinish +
                ", regionName='" + regionName + '\'' +
                ", project='" + project + '\'' +
                ", createAt=" + createAt +
                ", updatedAt=" + updatedAt +
                ", hasStop=" + hasStop +
                ", latitude=" + latitude +
                ", longitude=" + longitude +
                '}';
    }
}
